### Name: activeSetLogCon
### Title: Computes a Log-Concave Probability Density Estimate via an
###   Active Set Algorithm
### Aliases: activeSetLogCon activeSet log-concave logcondens
### Keywords: htest nonparametric

### ** Examples

## estimate gamma density
set.seed(1977)
x <- sort(rgamma(200, 2, 1))
res <- activeSetLogCon(x, w = NA, print = FALSE)

## plot resulting functions
par(mfrow = c(2, 2), mar = c(3, 2, 1, 2))
plot(x, exp(res$phi), type = 'l'); rug(x)
plot(x, res$phi, type = 'l'); rug(x)
plot(x, res$Fhat, type = 'l'); rug(x)
plot(x, res$H, type = 'l'); rug(x)

## compute and plot function values at an arbitrary point
x0 <- (x[100] + x[101]) / 2
Fx0 <- evaluateLogConDens(x0, x, res$phi, res$Fhat, res$IsKnot)[3]
plot(x, res$Fhat, type = 'l'); rug(x)
abline(v = x0, lty = 3); abline(h = Fx0, lty = 3)

## compute and plot 0.9-quantile of Fhat
q <- quantilesLogConDens(0.9, x, res$phi, res$Fhat)
plot(x, res$Fhat, type = 'l'); rug(x)
abline(h = 0.9, lty = 3); abline(v = q, lty = 3)



